@@ -1,11 +1,11 @@
 from .Image import Image
-from .Meta import PredictMeta, LivePredictMeta, TrainingMeta, EvaluationMeta
+from .Meta import PredictMeta, Meta, TrainingMeta, EvaluationMeta
 from .Model import Model, EvaluationModel
 
 __all__ = [
     Image,
     PredictMeta,
-    LivePredictMeta,
+    Meta,
     Model,
     EvaluationModel,
     TrainingMeta,
